'''
Input/Output functionality:

* Reading/Writing Simulation Definition Files
* Plotting/Logging results

.. image:: https://upload.wikimedia.org/wikipedia/commons/thumb/f/f8/Laptop-hard-drive-exposed.jpg/1280px-Laptop-hard-drive-exposed.jpg
'''